Index: trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeConstantNodeEditDialog.Designer.cs
===================================================================
--- trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeConstantNodeEditDialog.Designer.cs	(revision 17180)
+++ trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeConstantNodeEditDialog.Designer.cs	(revision 18132)
@@ -21,5 +21,5 @@
 
 namespace HeuristicLab.Problems.DataAnalysis.Symbolic.Views {
-  partial class ConstantNodeEditDialog {
+  partial class NumberNodeEditDialog {
     /// <summary>
     /// Required designer variable.
@@ -121,5 +121,5 @@
       this.cancelButton.Click += new System.EventHandler(this.cancelButton_Click);
       // 
-      // ConstantNodeEditDialog
+      // NumberNodeEditDialog
       // 
       this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
@@ -138,10 +138,10 @@
       this.MaximizeBox = false;
       this.MinimizeBox = false;
-      this.Name = "ConstantNodeEditDialog";
+      this.Name = "NumberNodeEditDialog";
       this.ShowIcon = false;
       this.ShowInTaskbar = false;
       this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
-      this.Text = "Edit constant value";
-      this.KeyDown += new System.Windows.Forms.KeyEventHandler(this.ConstantNodeEditDialog_KeyDown);
+      this.Text = "Edit number value";
+      this.KeyDown += new System.Windows.Forms.KeyEventHandler(this.NumberNodeEditDialog_KeyDown);
       ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).EndInit();
       this.ResumeLayout(false);
Index: trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeConstantNodeEditDialog.cs
===================================================================
--- trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeConstantNodeEditDialog.cs	(revision 17180)
+++ trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeConstantNodeEditDialog.cs	(revision 18132)
@@ -28,20 +28,20 @@
 
 namespace HeuristicLab.Problems.DataAnalysis.Symbolic.Views {
-  public partial class ConstantNodeEditDialog : Form {
-    private ConstantTreeNode constantTreeNode;
-    public ConstantTreeNode NewNode {
-      get { return constantTreeNode; }
+  public partial class NumberNodeEditDialog : Form {
+    private INumericTreeNode numberTreeNode;
+    public INumericTreeNode NewNode {
+      get { return numberTreeNode; }
       set {
         if (InvokeRequired)
-          Invoke(new Action<SymbolicExpressionTreeNode>(x => constantTreeNode = (ConstantTreeNode)x), value);
+          Invoke(new Action<SymbolicExpressionTreeNode>(x => numberTreeNode = (INumericTreeNode)x), value);
         else
-          constantTreeNode = value;
+          numberTreeNode = value;
       }
     }
 
-    public ConstantNodeEditDialog(ISymbolicExpressionTreeNode node) {
+    public NumberNodeEditDialog(ISymbolicExpressionTreeNode node) {
       InitializeComponent();
       oldValueTextBox.TabStop = false; // cannot receive focus using tab key
-      NewNode = (ConstantTreeNode)node;
+      NewNode = (INumericTreeNode)node;
       InitializeFields();
     }
@@ -49,8 +49,8 @@
     private void InitializeFields() {
       if (NewNode == null)
-        throw new ArgumentException("Node is not a constant.");
+        throw new ArgumentException("Node is not a number.");
       else {
-        this.Text = "Edit constant";
-        newValueTextBox.Text = oldValueTextBox.Text = Math.Round(constantTreeNode.Value, 4).ToString();
+        this.Text = "Edit number";
+        newValueTextBox.Text = oldValueTextBox.Text = Math.Round(numberTreeNode.Value, 4).ToString();
       }
     }
@@ -71,6 +71,5 @@
 
     private static bool ValidateNewValue(string value, out string errorMessage) {
-      double val;
-      bool valid = double.TryParse(value, out val);
+      bool valid = double.TryParse(value, out _);
       errorMessage = string.Empty;
       if (!valid) {
@@ -87,8 +86,8 @@
     // proxy handler passing key strokes to the parent control
     private void childControl_KeyDown(object sender, KeyEventArgs e) {
-      ConstantNodeEditDialog_KeyDown(sender, e);
+      NumberNodeEditDialog_KeyDown(sender, e);
     }
 
-    private void ConstantNodeEditDialog_KeyDown(object sender, KeyEventArgs e) {
+    private void NumberNodeEditDialog_KeyDown(object sender, KeyEventArgs e) {
       if ((e.KeyCode == Keys.Enter) || (e.KeyCode == Keys.Return)) {
         if (!ValidateChildren()) return;
@@ -100,10 +99,10 @@
     public event EventHandler DialogValidated;
     private void OnDialogValidated(object sender, EventArgs e) {
-      if (constantTreeNode == null) return;
+      if (numberTreeNode == null) return;
       var value = double.Parse(newValueTextBox.Text);
       // we impose an extra validation condition: that the new value is different from the original value
-      if (constantTreeNode.Value.Equals(value)) return;
+      if (numberTreeNode.Value.Equals(value)) return;
 
-      constantTreeNode.Value = value;
+      numberTreeNode.Value = value;
       DialogResult = DialogResult.OK;
       var dialogValidated = DialogValidated;
Index: trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeNodeInsertDialog.Designer.cs
===================================================================
--- trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeNodeInsertDialog.Designer.cs	(revision 17180)
+++ trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeNodeInsertDialog.Designer.cs	(revision 18132)
@@ -52,6 +52,6 @@
       this.variableNamesCombo = new System.Windows.Forms.ComboBox();
       this.variableWeightTextBox = new System.Windows.Forms.TextBox();
-      this.constantValueTextBox = new System.Windows.Forms.TextBox();
-      this.constantValueLabel = new System.Windows.Forms.Label();
+      this.numberValueTextBox = new System.Windows.Forms.TextBox();
+      this.numberValueLabel = new System.Windows.Forms.Label();
       this.errorProvider = new System.Windows.Forms.ErrorProvider(this.components);
       this.okButton = new System.Windows.Forms.Button();
@@ -121,23 +121,23 @@
       this.variableWeightTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.variableWeightTextBox_Validating);
       // 
-      // constantValueTextBox
-      // 
-      this.constantValueTextBox.Location = new System.Drawing.Point(101, 37);
-      this.constantValueTextBox.Name = "constantValueTextBox";
-      this.constantValueTextBox.Size = new System.Drawing.Size(127, 20);
-      this.constantValueTextBox.TabIndex = 7;
-      this.constantValueTextBox.Text = "0.0";
-      this.constantValueTextBox.Visible = false;
-      this.constantValueTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.constantValueTextBox_Validating);
-      // 
-      // constantValueLabel
-      // 
-      this.constantValueLabel.AutoSize = true;
-      this.constantValueLabel.Location = new System.Drawing.Point(19, 40);
-      this.constantValueLabel.Name = "constantValueLabel";
-      this.constantValueLabel.Size = new System.Drawing.Size(34, 13);
-      this.constantValueLabel.TabIndex = 8;
-      this.constantValueLabel.Text = "Value";
-      this.constantValueLabel.Visible = false;
+      // numberValueTextBox
+      // 
+      this.numberValueTextBox.Location = new System.Drawing.Point(101, 37);
+      this.numberValueTextBox.Name = "numberValueTextBox";
+      this.numberValueTextBox.Size = new System.Drawing.Size(127, 20);
+      this.numberValueTextBox.TabIndex = 7;
+      this.numberValueTextBox.Text = "0.0";
+      this.numberValueTextBox.Visible = false;
+      this.numberValueTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.numberValueTextBox_Validating);
+      // 
+      // numberValueLabel
+      // 
+      this.numberValueLabel.AutoSize = true;
+      this.numberValueLabel.Location = new System.Drawing.Point(19, 40);
+      this.numberValueLabel.Name = "numberValueLabel";
+      this.numberValueLabel.Size = new System.Drawing.Size(34, 13);
+      this.numberValueLabel.TabIndex = 8;
+      this.numberValueLabel.Text = "Value";
+      this.numberValueLabel.Visible = false;
       // 
       // errorProvider
@@ -187,6 +187,6 @@
       this.Controls.Add(this.cancelButton);
       this.Controls.Add(this.okButton);
-      this.Controls.Add(this.constantValueLabel);
-      this.Controls.Add(this.constantValueTextBox);
+      this.Controls.Add(this.numberValueLabel);
+      this.Controls.Add(this.numberValueTextBox);
       this.Controls.Add(this.variableWeightTextBox);
       this.Controls.Add(this.variableNamesCombo);
@@ -211,7 +211,7 @@
     private System.Windows.Forms.Label variableWeightLabel;
     private System.Windows.Forms.Label variableNameLabel;
-    private System.Windows.Forms.Label constantValueLabel;
+    private System.Windows.Forms.Label numberValueLabel;
     private System.Windows.Forms.ErrorProvider errorProvider;
-    internal System.Windows.Forms.TextBox constantValueTextBox;
+    internal System.Windows.Forms.TextBox numberValueTextBox;
     internal System.Windows.Forms.TextBox variableWeightTextBox;
     internal System.Windows.Forms.ComboBox variableNamesCombo;
Index: trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeVariableNodeEditDialog.cs
===================================================================
--- trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeVariableNodeEditDialog.cs	(revision 17180)
+++ trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeVariableNodeEditDialog.cs	(revision 18132)
@@ -60,5 +60,5 @@
     private void InitializeFields() {
       if (NewNode == null)
-        throw new ArgumentException("Node is not a constant.");
+        throw new ArgumentException("Node is not a variable node.");
       else {
         this.Text = "Edit variable";

Index: trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeNodeInsertDialog.cs
===================================================================
--- trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeNodeInsertDialog.cs	(revision 17180)
+++ trunk/HeuristicLab.Problems.DataAnalysis.Symbolic.Views/3.4/TreeEditDialogs/SymbolicExpressionTreeNodeInsertDialog.cs	(revision 18132)
@@ -57,12 +57,12 @@
       var combo = (ComboBox)sender;
       var symbol = combo.Items[combo.SelectedIndex];
-      if (symbol is Constant) {
-        // add controls to the dialog for changing the constant value
+      if (symbol is Number) {
+        // add controls to the dialog for changing the number value
         variableNameLabel.Visible = false;
         variableNamesCombo.Visible = false;
         variableWeightLabel.Visible = false;
         variableWeightTextBox.Visible = false;
-        constantValueLabel.Visible = true;
-        constantValueTextBox.Visible = true;
+        numberValueLabel.Visible = true;
+        numberValueTextBox.Visible = true;
       } else if (symbol is VariableBase) {
         var variableSymbol = (VariableBase)symbol;
@@ -80,6 +80,6 @@
         variableWeightLabel.Visible = true;
         variableWeightTextBox.Visible = true;
-        constantValueLabel.Visible = false;
-        constantValueTextBox.Visible = false;
+        numberValueLabel.Visible = false;
+        numberValueTextBox.Visible = false;
         // add controls to the dialog for changing the variable name or weight
       } else {
@@ -88,6 +88,6 @@
         variableWeightLabel.Visible = false;
         variableWeightTextBox.Visible = false;
-        constantValueLabel.Visible = false;
-        constantValueTextBox.Visible = false;
+        numberValueLabel.Visible = false;
+        numberValueTextBox.Visible = false;
       }
     }
@@ -102,10 +102,10 @@
     }
 
-    private void constantValueTextBox_Validating(object sender, CancelEventArgs e) {
+    private void numberValueTextBox_Validating(object sender, CancelEventArgs e) {
       string errorMessage;
-      if (ValidateDoubleValue(constantValueTextBox.Text, out errorMessage)) return;
+      if (ValidateDoubleValue(numberValueTextBox.Text, out errorMessage)) return;
       e.Cancel = true;
-      errorProvider.SetError(constantValueTextBox, errorMessage);
-      constantValueTextBox.SelectAll();
+      errorProvider.SetError(numberValueTextBox, errorMessage);
+      numberValueTextBox.SelectAll();
     }
 